@@ -90,7 +90,7 @@ public:
     QQuickWebEngineView *q_ptr;
     QQuickWebEngineViewPrivate();
     ~QQuickWebEngineViewPrivate();
-    void destroy();
+    void releaseProfile() override;
     void initializeProfile();
     QtWebEngineCore::UIDelegatesManager *ui();
 
@@ -130,7 +130,7 @@ public:
     void didFindText(quint64, int) override;
     void didPrintPage(quint64 requestId, const QByteArray &result) override;
     void didPrintPageToPdf(const QString &filePath, bool success) override;
-    void passOnFocus(bool reverse) override;
+    bool passOnFocus(bool reverse) override;
     void javaScriptConsoleMessage(JavaScriptConsoleMessageLevel level, const QString& message, int lineNumber, const QString& sourceID) override;
     void authenticationRequired(QSharedPointer<QtWebEngineCore::AuthenticationDialogController>) override;
     void runMediaAccessPermissionRequest(const QUrl &securityOrigin, MediaRequestFlags requestFlags) override;
